==> dhall-bash-1.0.41-164-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-6QiwJkI9AdyJRzTd9tSazA
key:                  dhall-bash-1.0.41-6QiwJkI9AdyJRzTd9tSazA
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  786792eedcf524d2b33ad381b124e12c
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-6QiwJkI9AdyJRzTd9tSazA
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-KXmenYTki91GraQt2ymkdK
    neat-interpolation-0.5.1.4-LgltL8bGunlFCtvssaeg3T
    shell-escape-0.2.0-JnB3WbULDqJCehVwOitl5u text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-bash-1.0.41-167-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-bash.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-bash
version:              1.0.41
visibility:           public
id:                   dhall-bash-1.0.41-K2VbYWTVK464WWLcPnq34P
key:                  dhall-bash-1.0.41-K2VbYWTVK464WWLcPnq34P
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Compile Dhall to Bash
description:
    Use this package if you want to compile Dhall expressions to Bash.
    You can use this package as a library or an executable:

    * See the "Dhall.Bash" module if you want to use this package as a library

    * Use the @dhall-to-bash@ if you want an executable

    The "Dhall.Bash" module also contains instructions for how to use this
    package

category:             Compiler
abi:                  fd0093a8c766dab35ef326b7e4e1f55e
exposed:              True
exposed-modules:      Dhall.Bash
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-bash-1.0.41
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-bash
hs-libraries:         HSdhall-bash-1.0.41-K2VbYWTVK464WWLcPnq34P
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    dhall-1.42.3-6ivmxcjn5ctBDS3CQUifdU
    neat-interpolation-0.5.1.4-4VDX25yQx4CGEE32HBtT8D
    shell-escape-0.2.0-DRPQUhPPscECbiU0p4OdgC text-2.0.2

haddock-interfaces:   /usr/share/doc/dhall-bash/html/dhall-bash.haddock
haddock-html:         /usr/share/doc/dhall-bash/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
